@@ -471,6 +471,16 @@ STDMETHODIMP VLCPlaylist::get_isPlaying(VARIANT_BOOL* isPlaying)
     return S_OK;
 };
 
+STDMETHODIMP VLCPlaylist::get_currentItem(long* index)
+{
+    if( NULL == index )
+        return E_POINTER;
+
+    *index = Instance()->get_player().current_item();
+
+    return S_OK;
+};
+
 STDMETHODIMP VLCPlaylist::add(BSTR uri, VARIANT name, VARIANT options, long* item)
 {
     if( NULL == item )
@@ -1423,6 +1433,22 @@ STDMETHODIMP VLCControl2::get_VersionInfo(BSTR *version)
     return E_FAIL;
 };
 
+STDMETHODIMP VLCControl2::versionInfo(BSTR *version)
+{
+    if( NULL == version )
+        return E_POINTER;
+
+    const char *versionStr = libvlc_get_version();
+    if( NULL != versionStr )
+    {
+        *version = BSTRFromCStr(CP_UTF8, versionStr);
+
+        return (NULL == *version) ? E_OUTOFMEMORY : NOERROR;
+    }
+    *version = NULL;
+    return E_FAIL;
+};
+
 STDMETHODIMP VLCControl2::get_Visible(VARIANT_BOOL *isVisible)
 {
     if( NULL == isVisible )
