@@ -26,8 +26,6 @@
 
 #ifdef _WIN32
 
-#include <vlc/vlc.h>
-
 #include "win32_vlcwnd.h"
 #include "vlc_player_options.h"
 #include "vlc_player.h"
@@ -35,10 +33,21 @@
 struct VLCViewResources
 {
     VLCViewResources()
-        :hNewMessageBitmap(0), hDeFullscreenBitmap(0), hPauseBitmap(0),
+        :hNewMessageBitmap(0), hFullscreenBitmap(0), hDeFullscreenBitmap(0), hPauseBitmap(0),
          hPlayBitmap(0), hVolumeBitmap(0), hVolumeMutedBitmap(0),
          hBackgroundIcon(0)
     {};
+    ~VLCViewResources()
+    {
+        if( hNewMessageBitmap )   DeleteObject( hNewMessageBitmap );
+        if( hFullscreenBitmap )   DeleteObject( hFullscreenBitmap );
+        if( hDeFullscreenBitmap ) DeleteObject( hDeFullscreenBitmap );
+        if( hPauseBitmap )        DeleteObject( hPauseBitmap );
+        if( hPlayBitmap )         DeleteObject( hPlayBitmap );
+        if( hVolumeBitmap )       DeleteObject( hVolumeBitmap );
+        if( hVolumeMutedBitmap )  DeleteObject( hVolumeMutedBitmap );
+        if( hBackgroundIcon )     DestroyIcon ( hBackgroundIcon );
+    }
 
     HANDLE hNewMessageBitmap;
     HANDLE hFullscreenBitmap;
@@ -276,6 +285,7 @@ public:
     bool getNewMessageFlag() const
         {return _b_new_messages_flag;};
 public:
+    void OnKeyDownEvent(UINT uKeyMsg);
     void OnMouseEvent(UINT uMouseMsg);
 
 private:
