@@ -1,18 +1,29 @@
 #!/bin/sh
-
-OSX_VERSION="10.7"
-SDKROOT=`xcode-select -print-path`/Platforms/MacOSX.platform/Developer/SDKs/MacOSX$OSX_VERSION.sdk
-
 set -e
 
+info()
+{
+    local green="\033[1;32m"
+    local normal="\033[0m"
+    echo "[${green}build${normal}] $1"
+}
+
+OSX_VERSION="10.9"
+ARCH="x86_64"
+MINIMAL_OSX_VERSION="10.6"
+SDKROOT=`xcode-select -print-path`/Platforms/MacOSX.platform/Developer/SDKs/MacOSX$OSX_VERSION.sdk
+UNSTABLE=no
+
 usage()
 {
 cat << EOF
 usage: $0 [-v] [-d]
 
 OPTIONS
-   -v       Be more verbose
-   -d       Enable Debug
+   -v            Be more verbose
+   -u            Use unstable libvlc
+   -k <sdk>      Use the specified sdk (default: $SDKROOT for $ARCH)
+   -a <arch>     Use the specified arch (default: $ARCH)
 EOF
 }
 
@@ -33,7 +44,7 @@ info()
      echo "[${green}info${normal}] $1"
 }
 
-while getopts "hvsdk:" OPTION
+while getopts "hvua:k:" OPTION
 do
      case $OPTION in
          h)
@@ -43,7 +54,14 @@ do
          v)
              VERBOSE=yes
              ;;
-         d)  CONFIGURATION="--enable-debug"
+         u)
+             UNSTABLE=yes
+             ;;
+         a)
+             ARCH=$OPTARG
+             ;;
+         k)
+             SDKROOT=$OPTARG
              ;;
          ?)
              usage
@@ -63,6 +81,10 @@ if [ "x$1" != "x" ]; then
     exit 1
 fi
 
+if [ "$ARCH" = "i686" ]; then
+    MINIMAL_OSX_VERSION="10.5"
+fi
+
 export OSX_VERSION
 export SDKROOT
 
@@ -78,7 +100,11 @@ info "Preparing build dirs"
 spushd extras/macosx
 
 if ! [ -e vlc ]; then
+if [ "$UNSTABLE" = "yes" ]; then
 git clone git://git.videolan.org/vlc.git vlc
+else
+git clone git://git.videolan.org/vlc/vlc-2.2.git vlc
+fi
 fi
 
 spopd #extras/macosx
@@ -87,6 +113,8 @@ spopd #extras/macosx
 # Build time
 #
 
+export PATH="${npapi_root_dir}/extras/macosx/vlc/extras/tools/build/bin:${npapi_root_dir}/extras/macosx/contrib/${ARCH}-apple-darwin10/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11/bin"
+
 info "Building tools"
 spushd extras/macosx/vlc/extras/tools
 if ! [ -e build ]; then
@@ -98,19 +126,26 @@ info "Fetching contrib"
 
 spushd extras/macosx/vlc/contrib
 
-if ! [ -e 64bit-npapi ]; then
-mkdir 64bit-npapi
-cd 64bit-npapi
-../bootstrap --build=x86_64-apple-darwin10
-make prebuilt
+if ! [ -e ${ARCH}-npapi ]; then
+mkdir ${ARCH}-npapi
 fi
+cd ${ARCH}-npapi
+../bootstrap --build=${ARCH}-apple-darwin10 \
+ --disable-sout --disable-cddb --disable-bluray --disable-sdl \
+ --disable-sparkle --disable-bghudappkit --disable-growl --disable-goom \
+ --disable-SDL_image --disable-lua --disable-chromaprint \
+ --disable-caca --disable-upnp --disable-vncserver \
+ --disable-ncurses --disable-protobuf
+make fetch
+core_count=`sysctl -n machdep.cpu.core_count`
+make .gettext && AUTOPOINT=true make -j $core_count
 
 spopd
 
 export CC="xcrun clang"
 export CXX="xcrun clang++"
 export OBJC="xcrun clang"
-PREFIX="${npapi_root_dir}/extras/macosx/vlc/64bit_install_dir"
+PREFIX="${npapi_root_dir}/extras/macosx/vlc/${ARCH}-install"
 
 info "Configuring VLC"
 
@@ -122,30 +157,42 @@ spushd extras/macosx/vlc
 if ! [ -e configure ]; then
     ./bootstrap > ${out}
 fi
-if ! [ -e 64build ]; then
-    mkdir 64build
+if ! [ -e ${ARCH}-build ]; then
+    mkdir ${ARCH}-build
 fi
-cd 64build
+
+CONFIG_OPTIONS=""
+if [ "$ARCH" = "i686" ]; then
+    CONFIG_OPTIONS="--disable-vda"
+    export LDFLAGS="-Wl,-read_only_relocs,suppress"
+fi
+
+cd ${ARCH}-build
 ../configure \
-        --build=x86_64-apple-darwin10 \
+        --build=${ARCH}-apple-darwin10 \
         --disable-lua --disable-httpd --disable-vlm --disable-sout \
-        --disable-vcd --disable-dvdnav --disable-dvdread --disable-screen \
+        --disable-vcd --enable-dvdnav --enable-dvdread --disable-screen \
+        --disable-debug \
         --disable-macosx \
-        --enable-merge-ffmpeg \
+        --disable-notify \
+        --disable-projectm \
         --disable-growl \
-        --enable-faad \
+        --disable-faad \
+        --disable-bluray \
         --enable-flac \
         --enable-theora \
         --enable-shout \
         --disable-ncurses \
         --disable-twolame \
+        --disable-a52 \
         --enable-realrtsp \
         --enable-libass \
-        --enable-macosx-audio \
+        --disable-macosx-avfoundation \
+        --disable-macosx-dialog-provider \
         --disable-macosx-eyetv \
         --disable-macosx-qtkit \
-        --disable-macosx-avfoundation \
-        --enable-macosx-vout \
+        --disable-macosx-quartztext \
+        --disable-macosx-vlc-app \
         --disable-skins2 \
         --disable-xcb \
         --disable-caca \
@@ -153,14 +200,13 @@ cd 64build
         --disable-samplerate \
         --disable-upnp \
         --disable-goom \
-        --disable-macosx-dialog-provider \
         --disable-nls \
+        --disable-mad \
         --disable-sdl \
         --disable-sdl-image \
-        --disable-macosx-vlc-app \
-        --disable-dirac \
-	--with-macosx-sdk=$SDKROOT \
-        --with-macosx-version-min=10.6 \
+        --with-macosx-sdk=$SDKROOT \
+        --with-macosx-version-min=${MINIMAL_OSX_VERSION} \
+        ${CONFIG_OPTIONS} \
         --prefix=${PREFIX} > ${out}
 
 info "Compiling VLC"
@@ -178,8 +224,6 @@ info "Installing VLC"
 make install > ${out}
 cd ..
 
-find ${PREFIX}/lib/vlc/plugins -name *.dylib -type f -exec cp '{}' ${PREFIX}/lib/vlc/plugins \;
-
 info "Removing unneeded modules"
 blacklist="
 stats
@@ -231,7 +275,6 @@ logger
 visual
 fb
 aout_file
-yuv
 dummy
 invert
 sepia
@@ -245,8 +288,6 @@ colorthres
 antiflicker
 anaglyph
 remap
-bluray
-x264
 "
 
 for i in ${blacklist}
