@@ -1,14 +1,16 @@
 /*****************************************************************************
  * events.cpp: events for the VLC Plugin
  *****************************************************************************
- * Copyright (C) 2002-2009 the VideoLAN team
+ * Copyright (C) 2002-2012 VLC authors and VideoLAN
  * $Id$
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
- *          Damien Fouilleul <damienf@videolan.org>
  *          Jean-Paul Saman <jpsaman@videolan.org>
  *          Sergey Radionov <rsatom@gmail.com>
  *          Cheng Sun <chengsun9@gmail.com>
+ *          Yannick Brehon <y.brehon@qiplay.com>
+ *          Jean-Baptiste Kempf <jb@videolan.org>
+ *          JP Dinger <jpd@videolan.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,11 +33,12 @@
 /*****************************************************************************
  * Event Object
  *****************************************************************************/
-static void handle_input_event(const libvlc_event_t* event, void *param)
+void handle_input_event(const libvlc_event_t* event, void *param)
 {
     VlcPluginBase *plugin = (VlcPluginBase*)param;
     switch( event->type )
     {
+        case libvlc_MediaPlayerMediaChanged:
         case libvlc_MediaPlayerNothingSpecial:
         case libvlc_MediaPlayerOpening:
         case libvlc_MediaPlayerPlaying:
@@ -52,7 +55,7 @@ static void handle_input_event(const libvlc_event_t* event, void *param)
     }
 }
 
-static void handle_changed_event(const libvlc_event_t* event, void *param)
+void handle_changed_event(const libvlc_event_t* event, void *param)
 {
     uint32_t   npcount = 1;
     NPVariant *npparam = (NPVariant *) NPN_MemAlloc( sizeof(NPVariant) * npcount );
@@ -76,7 +79,7 @@ static void handle_changed_event(const libvlc_event_t* event, void *param)
             BOOLEAN_TO_NPVARIANT(event->u.media_player_pausable_changed.new_pausable, npparam[0]);
             break;
         case libvlc_MediaPlayerTitleChanged:
-            BOOLEAN_TO_NPVARIANT(event->u.media_player_title_changed.new_title, npparam[0]);
+            INT32_TO_NPVARIANT(event->u.media_player_title_changed.new_title, npparam[0]);
             break;
         case libvlc_MediaPlayerLengthChanged:
             DOUBLE_TO_NPVARIANT(event->u.media_player_length_changed.new_length, npparam[0]);
@@ -108,10 +111,9 @@ static vlcplugin_event_t vlcevents[] = {
     { "MediaPlayerLengthChanged", libvlc_MediaPlayerLengthChanged, handle_changed_event },
 };
 
-bool EventObj::init()
+EventObj::EventObj() : _em(NULL), _already_in_deliver(false)
 {
     plugin_lock_init(&lock);
-    return true;
 }
 
 EventObj::~EventObj()
@@ -129,14 +131,14 @@ void EventObj::deliver(NPP browser)
 
     for( ev_l::iterator iter = _elist.begin(); iter != _elist.end(); ++iter )
     {
+        NPVariant *params = iter->params();
+        uint32_t   count  = iter->count();
+
         for( lr_l::iterator j = _llist.begin(); j != _llist.end(); ++j )
         {
             if( j->event_type() == iter->event_type() )
             {
                 NPVariant result;
-                NPVariant *params = iter->params();
-                uint32_t   count  = iter->count();
-
                 NPObject *listener = j->listener();
                 assert( listener );
 
@@ -146,7 +148,9 @@ void EventObj::deliver(NPP browser)
                 for( uint32_t n = 0; n < count; n++ )
                 {
                     if( NPVARIANT_IS_STRING(params[n]) )
+                    {
                         NPN_MemFree( (void*) NPVARIANT_TO_STRING(params[n]).UTF8Characters );
+                    }
                     else if( NPVARIANT_IS_OBJECT(params[n]) )
                     {
                         NPN_ReleaseObject( NPVARIANT_TO_OBJECT(params[n]) );
@@ -171,29 +175,19 @@ void EventObj::callback(const libvlc_event_t* event,
     plugin_unlock(&lock);
 }
 
-vlcplugin_event_t *EventObj::find_event(const char *s) const
+vlcplugin_event_t *EventObj::find_event(const NPString &name) const
 {
     for( size_t i = 0; i < ARRAY_SIZE(vlcevents); i++ )
     {
-        if( strncmp(vlcevents[i].name, s, strlen(vlcevents[i].name)) == 0 )
+        if( strncmp(vlcevents[i].name, name.UTF8Characters, strlen(vlcevents[i].name)) == 0 )
             return &vlcevents[i];
     }
     return NULL;
 }
 
-const char *EventObj::find_name(const libvlc_event_t *event)
-{
-    for( size_t i = 0; i < ARRAY_SIZE(vlcevents); i++ )
-    {
-        if( vlcevents[i].libvlc_type == event->type )
-            return vlcevents[i].name;
-    }
-    return NULL;
-}
-
 bool EventObj::insert(const NPString &name, NPObject *listener, bool bubble)
 {
-    vlcplugin_event_t *event = find_event(name.UTF8Characters);
+    vlcplugin_event_t *event = find_event(name);
     if( !event )
         return false;
 
@@ -213,7 +207,7 @@ bool EventObj::insert(const NPString &name, NPObject *listener, bool bubble)
 
 bool EventObj::remove(const NPString &name, NPObject *listener, bool bubble)
 {
-    vlcplugin_event_t *event = find_event(name.UTF8Characters);
+    vlcplugin_event_t *event = find_event(name);
     if( !event )
         return false;
 
@@ -233,31 +227,31 @@ bool EventObj::remove(const NPString &name, NPObject *listener, bool bubble)
 
 void EventObj::hook_manager( libvlc_event_manager_t *em, void *userdata )
 {
+    if( !em )
+        return;
+
     _em = em;
 
-    if( _em )
+    /* attach all libvlc events we need */
+    for( size_t i = 0; i < ARRAY_SIZE(vlcevents); i++ )
     {
-        /* attach all libvlc events we care about */
-        for( size_t i = 0; i < ARRAY_SIZE(vlcevents); i++ )
-        {
-            libvlc_event_attach( _em, vlcevents[i].libvlc_type,
-                                      vlcevents[i].libvlc_callback,
-                                      userdata );
-        }
+        libvlc_event_attach( _em, vlcevents[i].libvlc_type,
+                vlcevents[i].libvlc_callback,
+                userdata );
     }
 }
 
 void EventObj::unhook_manager( void *userdata )
 {
-    if( _em )
+    if( !_em )
+        return;
+
+    /* detach all libvlc events */
+    for( size_t i = 0; i < ARRAY_SIZE(vlcevents); i++ )
     {
-        /* detach all libvlc events we cared about */
-        for( size_t i = 0; i < ARRAY_SIZE(vlcevents); i++ )
-        {
-            libvlc_event_detach( _em, vlcevents[i].libvlc_type,
-                                      vlcevents[i].libvlc_callback,
-                                      userdata );
-        }
+        libvlc_event_detach( _em, vlcevents[i].libvlc_type,
+                vlcevents[i].libvlc_callback,
+                userdata );
     }
 }
 
