@@ -1,11 +1,15 @@
 /*****************************************************************************
  * vlcshell.cpp: a VLC plugin for Mozilla
  *****************************************************************************
- * Copyright (C) 2002-2009 the VideoLAN team
+ * Copyright (C) 2002-2013 VLC authors and VideoLAN
  * $Id$
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Jean-Paul Saman <jpsaman@videolan.org>
+ *          Jean-Baptiste Kempf <jb@videolan.org>
+ *          Cheng Sun <chengsun9@gmail.com>
+ *          Felix Paul Kühne <fkuehne # videolan.org>
+ *          Damien Fouilleul <damienf@videolan.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -333,8 +337,6 @@ NPError NPP_SetWindow( NPP instance, NPWindow* window )
         return NPERR_NO_ERROR;
     }
 
-    p_plugin->getVLC();
-
     /*
      * PLUGIN DEVELOPERS:
      *  Before setting window to point to the
