@@ -1,10 +1,11 @@
 /*****************************************************************************
  * vlcshell.h:
  *****************************************************************************
- * Copyright (C) 2009-2010 the VideoLAN team
+ * Copyright (C) 2009-2014 VLC authors and VideoLAN
  * $Id$
  *
  * Authors: Jean-Paul Saman <jpsaman@videolan.org>
+ *          Cheng Sun <chengsun9@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,8 +68,8 @@ NPint16_t NPP_HandleEvent( NPP instance, void * event );
  ******************************************************************************/
 #define PLUGIN_NAME         "VLC Web Plugin"
 #define PLUGIN_DESCRIPTION \
-    "Version %s, copyright 1996-2012 VideoLAN and Authors" \
-    "<br />" \
+    "VLC media player Web Plugin %s<br />" \
+    "Copyright © 2002-2014 VLC authors and VideoLAN<br />" \
     "<a href=\"http://www.videolan.org/vlc/\">http://www.videolan.org/vlc/</a>"
 
 #endif
